@@ -1,6 +1,6 @@
 import os
 import singlearity as singlearity
-from singlearity import State, Player, Team, Venue, Atmosphere, Matchup, PaSim, ApiException
+from singlearity import State, Player, Team, Venue, Atmosphere, Matchup, ApiException
 from singlearity.rest import ApiException
 from pprint import pprint
 
@@ -17,5 +17,9 @@ configuration.host = os.environ.get("SINGLEARITY_API_SERVER", "http://beta3-api.
 # Enter a context with an instance of the API client
 with singlearity.ApiClient(configuration) as api_client:
     # Create an instance of the API class
-    sing = singlearity.DefaultApi(api_client)
+    sing = singlearity.APIsApi(api_client)
+    
+    #validate that we can connect to the singelarity server
     print(sing.hello())
+
+
